pub enum DFError {
Show 61 variants
IO(Error),
VarError(VarError),
MpscSend(String),
SendTimeout,
HashRing(String),
NoSpace(String),
HostNotFound(String),
TaskNotFound(String),
PieceNotFound(String),
PieceStateIsFailed(String),
DownloadPieceFinishedTimeout(String),
WaitForPieceFinishedTimeout(String),
AvailableManagerNotFound,
AvailableSchedulersNotFound,
DownloadFromParentFailed(DownloadFromParentFailed),
ColumnFamilyNotFound(String),
InvalidStateTransition(String, String),
InvalidState(String),
InvalidURI(String),
InvalidPeer(String),
SchedulerClientNotFound,
UnexpectedResponse,
DigestMismatch(String, String),
ContentLengthMismatch(u64, u64),
MaxScheduleCountExceeded(u32),
InvalidContentLength,
InvalidPieceLength,
InvalidParameter,
NetAddrParseError(AddrParseError),
ConvertInfallible(Infallible),
Utf8(Utf8Error),
MutexPoisoned(String),
Unknown(String),
Unimplemented,
PermissionDenied,
EmptyHTTPRangeError,
Unauthorized,
ArrayTryFromSliceError(TryFromSliceError),
VortexProtocolStatus(Code, String),
VortexProtocolError(Error),
TonicStatus(Status),
TonicTransportError(Error),
TonicReflectionServerError(Error),
TokioStreamElapsed(Elapsed),
TokioTimeErrorElapsed(Elapsed),
HTTTHeaderInvalidHeaderName(InvalidHeaderName),
HTTTHeaderInvalidHeaderValue(InvalidHeaderValue),
HTTTHeaderToStrError(ToStrError),
URLParseError(ParseError),
ReqwestError(Error),
ReqwestMiddlewareError(Error),
OpenDALError(Error),
HyperError(Error),
BackendError(Box<BackendError>),
HyperUtilClientLegacyError(Error),
ExternalError(ExternalError),
MaxDownloadFilesExceeded(usize),
Unsupported(String),
TokioJoinError(JoinError),
ValidationError(String),
CgroupsFSError(Error),
}Expand description
The error for dragonfly.
Variants
IO(Error)
The error for IO operation.
VarError(VarError)
The error for environment variable.
MpscSend(String)
The error for send.
SendTimeout
The error for send timeout.
HashRing(String)
The error for hashring.
NoSpace(String)
The error when there is no space left on device.
HostNotFound(String)
The error when the host is not found.
TaskNotFound(String)
The error when the task is not found.
PieceNotFound(String)
The error when the piece is not found.
PieceStateIsFailed(String)
The error when the piece state is failed.
DownloadPieceFinishedTimeout(String)
The error when the download piece finished timeout.
WaitForPieceFinishedTimeout(String)
The error when the wait for piece finished timeout.
AvailableManagerNotFound
The error when the available manager is not found.
AvailableSchedulersNotFound
The error when the available schedulers is not found.
DownloadFromParentFailed(DownloadFromParentFailed)
The error when the download from parent is failed.
ColumnFamilyNotFound(String)
The error when the column family is not found.
InvalidStateTransition(String, String)
The error when the state transition is invalid.
InvalidState(String)
The error when the state is invalid.
InvalidURI(String)
The error when the uri is invalid.
InvalidPeer(String)
The error when the peer is invalid.
SchedulerClientNotFound
The error when the scheduler client is not found.
UnexpectedResponse
The error when the response is unexpected.
DigestMismatch(String, String)
The error when the digest is mismatch.
ContentLengthMismatch(u64, u64)
The error when the content length is mismatch.
MaxScheduleCountExceeded(u32)
The error when the max schedule count is exceeded.
InvalidContentLength
The error when the content length is invalid.
InvalidPieceLength
The error when the piece length is invalid.
InvalidParameter
The error when the parameter is invalid.
NetAddrParseError(AddrParseError)
The error for net address parse.
ConvertInfallible(Infallible)
The error for infallible.
Utf8(Utf8Error)
The error for utf8.
MutexPoisoned(String)
The error when the mutex is poisoned.
Unknown(String)
The error when the error is unknown.
Unimplemented
The error when the feature is not implemented.
PermissionDenied
The error when the permission is denied.
EmptyHTTPRangeError
The error when the range fallback error is empty.
The error for unauthorized.
ArrayTryFromSliceError(TryFromSliceError)
The error for array try from slice.
VortexProtocolStatus(Code, String)
The error for vortex protocol status.
VortexProtocolError(Error)
The error for vortex protocol.
TonicStatus(Status)
The error for tonic status.
TonicTransportError(Error)
The error for tonic transport.
TonicReflectionServerError(Error)
The error for tonic reflection server.
TokioStreamElapsed(Elapsed)
The error for tonic stream elapsed.
TokioTimeErrorElapsed(Elapsed)
HTTTHeaderInvalidHeaderName(InvalidHeaderName)
HTTTHeaderInvalidHeaderValue(InvalidHeaderValue)
HTTTHeaderToStrError(ToStrError)
URLParseError(ParseError)
The error for url parse.
ReqwestError(Error)
The error for reqwest.
ReqwestMiddlewareError(Error)
The error for reqwest middleware.
OpenDALError(Error)
The error for opendal.
HyperError(Error)
The error for hyper.
BackendError(Box<BackendError>)
The error for backend.
HyperUtilClientLegacyError(Error)
The error for hyper util client legacy.
ExternalError(ExternalError)
The error for external error.
MaxDownloadFilesExceeded(usize)
The error for max download files exceeded.
Unsupported(String)
The error for unsupported.
TokioJoinError(JoinError)
The error for tokio join.
ValidationError(String)
The error for validate.
CgroupsFSError(Error)
The error for cgroups fs.